# Generated by roxygen2: do not edit by hand

S3method(anova,pspatreg)
S3method(coef,pspatreg)
S3method(fitted,pspatreg)
S3method(logLik,pspatreg)
S3method(print,pspatreg)
S3method(print,summary.impactspar.pspatreg)
S3method(print,summary.pspatreg)
S3method(residuals,pspatreg)
S3method(summary,impactspar.pspatreg)
S3method(summary,pspatreg)
S3method(vcov,pspatreg)
export(fit_terms)
export(impactsnopar)
export(impactspar)
export(plot_impactsnopar)
export(plot_sp2d)
export(plot_sp3d)
export(plot_sptime)
export(plot_terms)
export(pspatfit)
export(pspl)
export(pspt)
importFrom(AmesHousing,make_ames)
importFrom(MASS,ginv)
importFrom(MASS,mvrnorm)
importFrom(MBA,mba.surf)
importFrom(Matrix,Diagonal)
importFrom(Matrix,Matrix)
importFrom(Matrix,bandSparse)
importFrom(Matrix,bdiag)
importFrom(Matrix,crossprod)
importFrom(Matrix,determinant)
importFrom(Matrix,diag)
importFrom(Matrix,kronecker)
importFrom(Matrix,rowSums)
importFrom(Matrix,solve)
importFrom(Matrix,t)
importFrom(Matrix,tcrossprod)
importFrom(Rdpack,reprompt)
importFrom(dplyr,left_join)
importFrom(fields,image.plot)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylim)
importFrom(grDevices,hcl.colors)
importFrom(grDevices,heat.colors)
importFrom(graphics,abline)
importFrom(graphics,contour)
importFrom(graphics,image)
importFrom(graphics,lines)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,title)
importFrom(methods,as)
importFrom(minqa,bobyqa)
importFrom(numDeriv,hessian)
importFrom(plm,Between)
importFrom(plm,Within)
importFrom(plm,index)
importFrom(plm,pdata.frame)
importFrom(plm,plm)
importFrom(sf,st_as_sf)
importFrom(sf,st_coordinates)
importFrom(sf,st_drop_geometry)
importFrom(sf,st_geometry_type)
importFrom(spatialreg,can.be.simmed)
importFrom(spatialreg,create_WX)
importFrom(spatialreg,do_ldet)
importFrom(spatialreg,get.ZeroPolicyOption)
importFrom(spatialreg,intImpacts)
importFrom(spatialreg,invIrW)
importFrom(spatialreg,jacobianSetup)
importFrom(spatialreg,lmSLX)
importFrom(spatialreg,trW)
importFrom(spdep,knearneigh)
importFrom(spdep,knn2nb)
importFrom(spdep,listw2mat)
importFrom(spdep,mat2listw)
importFrom(spdep,nb2listw)
importFrom(splines,spline.des)
importFrom(stats,.getXlevels)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,coefficients)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,lag)
importFrom(stats,loess)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.action)
importFrom(stats,napredict)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_length)
importFrom(stringr,str_replace)
importFrom(stringr,str_split)
